<object width="{{width}}" height="{{height}}">
  <param name="movie" value="{{object.url|safe}}"></param>
  <param name="allowFullScreen" value="true"></param>
  <param name="allowscriptaccess" value="always"></param>
  <embed src="{{object.url|safe}}" type="application/x-shockwave-flash"
           allowscriptaccess="always" allowfullscreen="true"
           width="{{width}}" height="{{height}}">
  </embed>
</object>
