{% load i18n %}
{% if form %}
<form method="post" action="{{ form_url }}" class="add-video">
    {% csrf_token %}
    <input type="hidden" name="next" value="{{ next }}"/>
    {{ form.as_p }}
    <p class="submit">
        <input type="submit" value="{% trans "Add video" %}"/>
    </p>
</form>
{% endif %}
